==> Evergreen-ILS-3.15.7.tar.gz: Evergreen-ILS-3.15.7/Open-ILS/web/js/dojo/openils/opac/nls/pt-br/opac.js <==
{
    ":BARCODE_PROMPT": "C\u00f3digo de Barras ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Cancelar",
    ":SUBMIT_BUTTON_LABEL": "Enviar",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Resposta de redefini\u00e7\u00e3o de senha",
    ":PWD_RESET_SUBMIT_SUCCESS": "Sua solicita\u00e7\u00e3o para iniciar o processo de redefini\u00e7\u00e3o de senha foi processada Se a sua conta tiver um endere\u00e7o de e-mail v\u00e1lido, voc\u00ea dever\u00e1 receber em breve um e-mail contendo novas instru\u00e7\u00f5es para redefinir a sua senha.",
    ":PWD_RESET_SUBMIT_ERROR": "O sistema n\u00e3o p\u00f4de processar seu pedido de redefini\u00e7\u00e3o de senha. Por favor, tente novamente ou contate o pessoal administrativo para assist\u00eancia.",
    ":PWD_RESET_SUBMIT_STATUS": "Enviando solicita\u00e7\u00e3o...",
    ":PWD_RESET_FORGOT_PROMPT": "Esqueceu sua senha?",
    ":PWD_RESET_FORM_TITLE": "Solicita\u00e7\u00e3o de redefini\u00e7\u00e3o de senha",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "Incluir Registro  MFHD",
    ":CREATED_MFHD_RECORD": "Criar um registro MFHD para ${0}",
    ":DELETE_MFHD": "Excluir Registro",
    ":DELETE_MFHD_CONFIRM": "Voc\u00ea tem certeza que deseja excluir este peri\u00f3dico?",
    ":DELETED_MFHD_RECORD": "Excluir registro MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Editar Registro",
    ":EDIT_MFHD_MENU": "Editar Reservas",
    ":EDIT_PROPERTIES": "Editar Propriedades",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Informa\u00e7\u00f5es extras do volume",
    ":INDEX_HOLDINGS": "\u00cdndices",
    ":INDEX_HOLDINGS_ADD": "Informa\u00e7\u00f5es extras de \u00edndice",
    ":CURRENT_HOLDINGS": "Volume atual",
    ":CURRENT_INDEXES": "\u00cdndices atuais",
    ":CURRENT_SUPPLEMENTS": "Suplementos atuais",
    ":HOLDINGS_TABLE_CAPTION": "S\u00famario de reservas (${0})",
    ":INCOMPLETE_VOLUMES": "Volumes incompletos",
    ":MISSING_VOLUMES": "Volumes em falta",
    ":ONLINE_VOLUMES": "Volumes online",
    ":SAVE_MFHD_LABEL": "Salvar MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suplementos",
    ":SUPPLEMENT_HOLDINGS_ADD": "Informa\u00e7\u00f5es Suplementares extras",
    ":PLACE_HOLD": "Reservar",
    ":HOLD_STATUS_PLURAL": "Reserva # ${0} de ${1} totais reservados e ${2} itens em potencial",
    ":HOLD_STATUS_SINGULAR": "reserva # $(0) de (1) reservas totais e $(2) item em potencial",
    ":MORE": "Mais",
    ":MORE_COPIES_FULL_RECORD": "... mais c\u00f3pias listadas com registro completo",
    ":SOURCE_CANNOT_HAVE_COPIES": "Registros a partir de $(0) n\u00e3o podem possuir c\u00f3pias."
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/opac/nls/pt-br/opac.js <==
{
    ":BARCODE_PROMPT": "C\u00f3digo de Barras ",
    ":USERNAME_PROMPT": "Nome de usu\u00e1rio: ",
    ":CANCEL_BUTTON_LABEL": "Cancelar",
    ":SUBMIT_BUTTON_LABEL": "Enviar",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Resposta de redefini\u00e7\u00e3o de senha",
    ":PWD_RESET_SUBMIT_SUCCESS": "Sua solicita\u00e7\u00e3o para iniciar o processo de redefini\u00e7\u00e3o de senha foi processada Se a sua conta tiver um endere\u00e7o de e-mail v\u00e1lido, voc\u00ea dever\u00e1 receber em breve um e-mail contendo novas instru\u00e7\u00f5es para redefinir a sua senha.",
    ":PWD_RESET_SUBMIT_ERROR": "O sistema n\u00e3o p\u00f4de processar seu pedido de redefini\u00e7\u00e3o de senha. Por favor, tente novamente ou contate o pessoal administrativo para assist\u00eancia.",
    ":PWD_RESET_SUBMIT_STATUS": "Enviando solicita\u00e7\u00e3o...",
    ":PWD_RESET_FORGOT_PROMPT": "Esqueceu sua senha?",
    ":PWD_RESET_FORM_TITLE": "Solicita\u00e7\u00e3o de redefini\u00e7\u00e3o de senha",
    ":PWD_RESET_SUBMIT_PROMPT": "Para iniciar o processo de redefini\u00e7\u00e3o de senha, digite seu nome ou c\u00f3digo de barras ou nome de usu\u00e1rio no formul\u00e1rio abaixo e clique em \"Enviar\"",
    ":CREATE_MFHD": "Incluir Registro  MFHD",
    ":CREATED_MFHD_RECORD": "Criar um registro MFHD para ${0}",
    ":DELETE_MFHD": "Excluir Registro",
    ":DELETE_MFHD_CONFIRM": "Voc\u00ea tem certeza que deseja excluir este peri\u00f3dico?",
    ":DELETED_MFHD_RECORD": "Excluir registro MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Editar Registro",
    ":EDIT_MFHD_MENU": "Editar Reservas",
    ":EDIT_PROPERTIES": "Editar Propriedades",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Informa\u00e7\u00f5es extras do volume",
    ":INDEX_HOLDINGS": "\u00cdndices",
    ":INDEX_HOLDINGS_ADD": "Informa\u00e7\u00f5es extras de \u00edndice",
    ":CURRENT_HOLDINGS": "Volume atual",
    ":CURRENT_INDEXES": "\u00cdndices atuais",
    ":CURRENT_SUPPLEMENTS": "Suplementos atuais",
    ":HOLDINGS_TABLE_CAPTION": "S\u00famario de reservas (${0})",
    ":INCOMPLETE_VOLUMES": "Volumes incompletos",
    ":MISSING_VOLUMES": "Volumes em falta",
    ":ONLINE_VOLUMES": "Volumes online",
    ":SAVE_MFHD_LABEL": "Salvar MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suplementos",
    ":SUPPLEMENT_HOLDINGS_ADD": "Informa\u00e7\u00f5es Suplementares extras",
    ":PLACE_HOLD": "Reservar",
    ":HOLD_STATUS_PLURAL": "Reserva # ${0} de ${1} totais reservados e ${2} itens em potencial",
    ":HOLD_STATUS_SINGULAR": "reserva # $(0) de (1) reservas totais e $(2) item em potencial",
    ":MORE": "Mais",
    ":MORE_COPIES_FULL_RECORD": "... mais c\u00f3pias listadas com registro completo",
    ":SOURCE_CANNOT_HAVE_COPIES": "Registros a partir de $(0) n\u00e3o podem possuir c\u00f3pias."
}
